<?php
/**
 * Donohoe-Financial functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Donohoe-Financial
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.0' );
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function donohoe_financial_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on Donohoe-Financial, use a find and replace
		* to change 'donohoe-financial' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'donohoe-financial', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'menu-1' => esc_html__( 'Primary', 'donohoe-financial' ),
			'footer_menu' => esc_html__( 'Footer', 'donohoe-financial' ),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'donohoe_financial_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
}
add_action( 'after_setup_theme', 'donohoe_financial_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function donohoe_financial_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'donohoe_financial_content_width', 640 );
}
add_action( 'after_setup_theme', 'donohoe_financial_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function donohoe_financial_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'donohoe-financial' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'donohoe-financial' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'donohoe_financial_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function donohoe_financial_scripts() {

	wp_enqueue_style('donohoe-financial-bootstrap-min', get_template_directory_uri() . '/assets/css/bootstrap.min.css', array(), '20151215');
	wp_enqueue_style('donohoe-financial-animate', get_template_directory_uri() . '/assets/css/animate.min.css', array(), '20151215');
	wp_enqueue_style('donohoe-financial-slick', get_template_directory_uri() . '/assets/css/slick.css', array(), '20151215');
	wp_enqueue_style('donohoe-financial-slick-theme', get_template_directory_uri() . '/assets/css/slick-theme.css', array(), '20151215');
	wp_enqueue_style('donohoe-financial-datetimepicker-css', get_template_directory_uri() . '/assets/css/jquery.datetimepicker.min.css', array(), '20151215');
	wp_enqueue_style('donohoe-financial-fancybox-min', get_template_directory_uri() . '/assets/css/jquery.fancybox.min.css', array(), '20151215');
	wp_enqueue_style('donohoe-financial-simplebar-css', get_template_directory_uri() . '/assets/css/simplebar.css', array(), '20151215');

	wp_enqueue_style( 'donohoe-financial-style', get_stylesheet_uri(), array(), _S_VERSION );
	wp_enqueue_script('jquery');
	wp_style_add_data( 'donohoe-financial-style', 'rtl', 'replace' );

	// wp_enqueue_script('donohoe-financial-jquery-slim', get_template_directory_uri() . '/assets/js/jquery-3.3.1.slim.min.js', array(), '20151215', true);
	wp_enqueue_script('donohoe-financial-jquery-ui-min-js', get_template_directory_uri() . '/assets/js/jquery-ui.min.js', array(), '20151215', true);
	wp_enqueue_script('donohoe-financial-jquery-touch-punch-js', get_template_directory_uri() . '/assets/js/jquery.ui.touch-punch.min.js', array(), '20151215', true);
	wp_enqueue_script('donohoe-financial-popper-js', get_template_directory_uri() . '/assets/js/popper.min.js', array(), '20151215', true);
	wp_enqueue_script('donohoe-financial-bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array(), '20151215', true);
	wp_enqueue_script('donohoe-financial-simplebar-js', get_template_directory_uri() . '/assets/js/simplebar.js', array(), '20151215', true);
	wp_enqueue_script('donohoe-financial-slick', get_template_directory_uri() . '/assets/js/slick.min.js', array(), '20151215', true);
	wp_enqueue_script('donohoe-financial-datetimepicker', get_template_directory_uri() . '/assets/js/jquery.datetimepicker.full.min.js', array(), '20151215', true);
	wp_enqueue_script('donohoe-financial-fancybox-min', get_template_directory_uri() . '/assets/js/jquery.fancybox.min.js', array(), '20151215', true);
	wp_enqueue_script('donohoe-financial-wow-min', get_template_directory_uri() . '/assets/js/wow.min.js', array(), '20151215', true);
	wp_enqueue_script('donohoe-financial-font-awesome-min', get_template_directory_uri() . '/assets/js/font-awesome.min.js', array(), '20151215', true);
	wp_enqueue_script('donohoe-financial-custom', get_template_directory_uri() . '/assets/js/custom.js', array(), rand(1000, 10000), true);
	wp_localize_script('donohoe-financial-custom', 'custom_call', ['ajaxurl' => admin_url('admin-ajax.php')]);


	wp_enqueue_script( 'donohoe-financial-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'donohoe_financial_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

// Filter the output of logo to fix Googles Error about itemprop logo
add_filter( 'get_custom_logo', 'change_html_custom_logo' );
function change_html_custom_logo() {
    $custom_logo_id = get_theme_mod( 'custom_logo' );
	$site_name = get_bloginfo( 'name' );
    $html = sprintf( '<a href="%1$s" class="custom-logo-link" rel="home" title="'.$site_name.'">%2$s</a>',
            esc_url( home_url( '/' ) ),
            wp_get_attachment_image( $custom_logo_id, 'full', false, array(
                'class'    => 'custom-logo',
            ) )
        );
    return $html;   
}

if( function_exists('acf_add_options_page') ) {

    acf_add_options_page();

}

function clean_html_output($buffer) {
    // Remove trailing slashes from void elements
    $voidTags = ['br', 'img', 'input', 'hr', 'meta', 'link', 'area', 'base', 'col', 'command', 'embed', 'keygen', 'param', 'source', 'track', 'wbr'];
    foreach ($voidTags as $tag) {
        $pattern = '/<' . $tag . '\b([^>]*)\/>/i';
        $replacement = '<' . $tag . '$1>';
        $buffer = preg_replace($pattern, $replacement, $buffer);
    }

    // Remove type="text/javascript" from script tags
    $buffer = str_replace('type="text/javascript"', '', $buffer);

    return $buffer;
}

function start_output_buffer_for_cleaning() {
    ob_start('clean_html_output');
}

add_action('template_redirect', 'start_output_buffer_for_cleaning');

add_action('template_redirect', function () {
    ob_start(function ($buffer) {
        return str_replace(
            'type="speculationrules"',
            'type="application/speculationrules"',
            $buffer
        );
    });
});

function remove_auto_sizes_css_fix($add_auto_sizes) {return false;}
add_filter('wp_img_tag_add_auto_sizes', 'remove_auto_sizes_css_fix');


